==> apache-nuttx-12.0.0.tar.gz: nuttx/libs/libc/string/lib_strdup.c <==
/****************************************************************************
 * libs/libc/string/lib_strdup.c
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>

#include <string.h>

#include "libc.h"

/****************************************************************************
 * Public Functions
 ****************************************************************************/

#undef strdup /* See mm/README.txt */
FAR char *strdup(FAR const char *s)
{
  FAR char *news = (FAR char *)lib_malloc(strlen(s) + 1);

  if (news)
    {
      strcpy(news, s);
    }

  return news;
}

==> apache-nuttx-12.2.1.tar.gz: nuttx/libs/libc/string/lib_strdup.c <==
/****************************************************************************
 * libs/libc/string/lib_strdup.c
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>

#include <string.h>

#include "libc.h"

/****************************************************************************
 * Public Functions
 ****************************************************************************/

#undef strdup /* See mm/README.txt */
FAR char *strdup(FAR const char *s)
{
  size_t size = strlen(s) + 1;
  FAR char *news = (FAR char *)lib_malloc(size);

  if (news)
    {
      strlcpy(news, s, size);
    }

  return news;
}
